#include "assets.hpp"

AssetManager::AssetManager() {
}

AssetManager::~AssetManager() {
    clearAssets();
}

void AssetManager::load(const std::string& name, const std::string& filePath) {
    SDL_Surface* surface = IMG_Load(filePath.c_str());
    if (!surface) {
        SDL_Log("Failed to load image %s: %s", filePath.c_str(), SDL_GetError());
    }
    assets[name] = surface;
}

SDL_Surface* AssetManager::getAsset(const std::string& name) const {
    auto it = assets.find(name);
    if (it != assets.end()) {
        return it->second;
    }
    SDL_Log("Asset %s not found", name.c_str());
    return nullptr;
}

void AssetManager::unloadAsset(const std::string& name) {
    auto it = assets.find(name);
    if (it != assets.end()) {
        SDL_DestroySurface(it->second);
        assets.erase(it);
    }
    SDL_Log("Asset %s not found", name.c_str());
}

void AssetManager::clearAssets() {
    for (auto& pair : assets) {
        SDL_DestroySurface(pair.second);
    }
    assets.clear();
}

TileMap::TileMap(AssetManager& assetManager)
    : assetManager(assetManager) {
}

TileMap::~TileMap() {
    clear();
}

void TileMap::addTile(const std::string& name, const Tile& tile) {
    tiles[name] = tile;
}

Tile TileMap::getTile(const std::string& name) const {
    auto it = tiles.find(name);
    if (it != tiles.end()) {
        return it->second;
    }
    SDL_Log("Tile %s not found", name.c_str());
    return Tile(); // Return an empty Tile
}

SDL_Surface* TileMap::getTileAsset(const std::string& name) const {
    auto it = tiles.find(name);
    if (it != tiles.end()) {
        return assetManager.getAsset(it->second.assetName);
    }
    SDL_Log("Tile %s not found", name.c_str());
    return nullptr;
}

Rect TileMap::getTileRect(const std::string& name) const {
    auto it = tiles.find(name);
    if (it != tiles.end()) {
        return Rect(it->second.srcRect);
    }
    SDL_Log("Tile %s not found", name.c_str());
    return Rect(); // Return an empty Rect
}

void TileMap::removeTile(const std::string& name) {
    auto it = tiles.find(name);
    if (it != tiles.end()) {
        tiles.erase(it);
    } else {
        SDL_Log("Tile %s not found", name.c_str());
    }
}

void TileMap::clear() {
    tiles.clear();
}