#include "engine.hpp"

// Main function
int main(int argc, char* argv[]) {
    // Create the engine with a window title and dimensions
    Engine engine("SDL3 Game Engine", 800, 600);
    TileMap tileMap(engine.assets);

    // Load bird asset
    engine.assets.load("bird", "assets/bird.png");
    tileMap.addTile("bird0", Tile{{0, 0, 34, 24}, "bird"});
    tileMap.addTile("bird1", Tile{{34, 0, 34, 24}, "bird"});
    tileMap.addTile("bird2", Tile{{68, 0, 34, 24}, "bird"});

    int currentBirdIndex = 0;

    // bird position
    Vector2 birdPosition(0, 0);

    while (!engine.input.quitRequested()) {
        // Start a new frame
        engine.startFrame();

        // Handle input events
        engine.input.handleEvents();

        // check for movement keys
        if (engine.input.isKeyPressed(SDL_SCANCODE_D)) {
            birdPosition.x += 1; // Move right
        }
        if (engine.input.isKeyPressed(SDL_SCANCODE_A)) {
            birdPosition.x -= 1; // Move left
        }
        if (engine.input.isKeyPressed(SDL_SCANCODE_W)) {
            birdPosition.y -= 1; // Move up
        }
        if (engine.input.isKeyPressed(SDL_SCANCODE_S)) {
            birdPosition.y += 1; // Move down
        }

        // Change bird sprite on space key press
        if (engine.input.hasKeyBeenPressed(SDL_SCANCODE_SPACE)) {
            currentBirdIndex = (currentBirdIndex + 1) % 3; // Cycle through bird sprites
        }

        // Clear the screen with a color
        engine.clearScreen({0, 0, 0}); // Black color

        // Draw the bird asset at a specific position
        engine.draw(tileMap.getTile("bird" + std::to_string(currentBirdIndex)), birdPosition);

        // Present the rendered frame
        engine.present();
    }
    
    return 0;
}